# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	Check if Makefile.PL has the right pre-requisites
Name:		perl-Test-Prereq
Version:	2.005
Release:	1.%{__distinit}%{__distvers}
License:	Artistic-2.0
URL:		https://metacpan.org/release/Test-Prereq
Source0:	https://cpan.metacpan.org/modules/by-module/Test/Test-Prereq-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter >= 4:5.22.0
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.76
BuildRequires:	perl(feature)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(Module::Build)
BuildRequires:	perl(Module::Extract::Use)
BuildRequires:	perl(parent)
BuildRequires:	perl(strict)
BuildRequires:	perl(Test::Builder::Module)
BuildRequires:	perl(utf8)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Cwd)
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::Builder::Tester)
BuildRequires:	perl(Test::More) >= 1.00
# Optional Tests
BuildRequires:	perl(Test::Manifest) >= 1.21
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Pod::Coverage)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
The prereq_ok() function examines the modules it finds in blib/lib/,
blib/script, and the test files it finds in t/ (and test.pl). It figures out
which modules they use and compares that list of modules to those in the
PREREQ_PM section of Makefile.PL.

If you use Module::Build, see Test::Prereq::Build instead.

%prep
%setup -q -n Test-Prereq-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor NO_PERLLOCAL=1 NO_PACKLIST=1
%{make_build}

%install
%{make_install}
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSE
%doc Changes README.pod SECURITY.md
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Prereq.3*
%{_mandir}/man3/Test::Prereq::Build.3*

%changelog
* Fri Jan  3 2025 Paul Howarth <paul@city-fan.org> - 2.005-1
- Update to 2.005
  - Refresh distro
  - Move to BRIANDFOY user
  - Add SECURITY.md policy
- Use %%{make_build} and %%{make_install}

* Fri May 26 2023 Paul Howarth <paul@city-fan.org> - 2.003-11
- Use SPDX-format license tag

* Fri Dec 20 2019 Paul Howarth <paul@city-fan.org> - 2.003-1
- Update to 2.003
  - Uniq the list of modules this extracts; Module::Extract::Use 1.045 changed
    slightly to return a bit more than it used to do

* Thu Jun  6 2019 Paul Howarth <paul@city-fan.org> - 2.002-9
- Perl 5.30 rebuild

* Thu Apr  5 2018 Paul Howarth <paul@city-fan.org> - 2.002-5
- BR: perl-interpreter rather than perl

* Thu Nov 24 2016 Paul Howarth <paul@city-fan.org> - 2.002-1
- Update to 2.002
  - No more filtering out core modules (some things are ejected from core!)
  - Switched from Module::Info to Module::Extract::Use
  - Switched from old Test::Builder to Test::Builder::Module
  - Fix postderef (GH#14)
  - Support test_requires in Module::Build (GH#15)
- Minimum perl supported is now 5.22, so drop legacy distribution support

* Tue Aug  2 2016 Paul Howarth <paul@city-fan.org> - 1.039-3
- Update CoreList patch to fix build on Perl 5.20.3
- BR: perl-generators where available
- Avoid installing README.pod with old ExtUtils::MakeMaker versions
- Simplify find command using -delete

* Sun Aug  9 2015 Paul Howarth <paul@city-fan.org> - 1.039-1
- Update to 1.039
  - Adjust default list for v5.20, kicking out Module::Build (Debian #789479,
    CPAN RT#105398)
  - Don't install README.pod
- Drop upstreamed patches
- License is now Artistic 2.0
- Update patches as needed

* Mon Jun 22 2015 Paul Howarth <paul@city-fan.org> - 1.038-4
- Incorporate changes from upstream dev release 1.038_05
  - Handle TEST_REQUIRES
  - Fixes for v5.8, which doesn't include Module::Build
  - Fixup for CONFIGURE_REQUIRES (GitHub Issue #2)
- Add workaround for FTBFS in Perl 5.22 (CPAN RT#105398)
- Add workaround for Module::CoreList issues with Perl 5.8
- Classify buildreqs by usage

* Mon Sep  1 2014 Paul Howarth <paul@city-fan.org> - 1.038-2
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Fri Jan  3 2014 Paul Howarth <paul@city-fan.org> - 1.038-1
- Update to 1.038
  - Use Makefile.PL instead of Build.PL since Module::Build is likely to be
    deprecated
  - Fix up Pod encoding issues
- Add patches to support building with old versions of ExtUtils::MakeMaker and
  Test::More

* Mon Jul  2 2012 Paul Howarth <paul@city-fan.org> - 1.037-9
- BR: perl(base), perl(Carp), perl(Cwd), perl(Exporter), perl(lib),
  perl(Test::Builder) and perl(Test::More)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Thu Jul  7 2011 Paul Howarth <paul@city-fan.org> - 1.037-7
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 1.037-4
- Rebuild for perl 5.12.1 in Rawhide

* Fri May 28 2010 Paul Howarth <paul@city-fan.org> - 1.037-3
- Fix dist tag for RHEL-6 Beta

* Wed Mar  3 2010 Paul Howarth <paul@city-fan.org> - 1.037-2
- Dist tag for Rawhide no longer needs special-casing
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation
- Buildreq perl(LWP::UserAgent) as preferred download method for CPAN
- Update CPAN.conf to work with current perl(CPAN)

* Mon Jun  1 2009 Paul Howarth <paul@city-fan.org> - 1.037-1
- Update to 1.037 (qualify calls to find() so Module::Install doesn't intercept
  them - RT #46335)
- Update to SLES-compatible dist tag macros

* Thu Jan 22 2009 Paul Howarth <paul@city-fan.org> - 1.036-1
- Update to 1.036

* Mon Aug  4 2008 Paul Howarth <paul@city-fan.org> - 1.034-1
- Update to 1.034
- Clarify license as GPL version 1 or later, or Artistic (i.e. same as perl)
- Tweak dist tag macros to work on current Rawhide with three-part releasenum

* Mon Mar 19 2007 Paul Howarth <paul@city-fan.org> - 1.033-1
- Update to 1.033
- Fix dist tag for Fedora 7 onwards
- BuildRequire perl(ExtUtils::MakeMaker)

* Wed Jan 10 2007 Paul Howarth <paul@city-fan.org> - 1.032-1
- Update to 1.032
- Fix argument order for find with -depth
- Include LICENSE file
- Add buildreqs perl(Test::Pod) and perl(Test::Pod::Coverage)

* Fri Sep  1 2006 Paul Howarth <paul@city-fan.org> - 1.031-2
- Fix distribution tags for development releases
- Provide CPAN config so that get_from_prereqs test doesn't hang
- Add buildreq perl(CPAN)

* Thu May 18 2006 Paul Howarth <paul@city-fan.org> - 1.031-1
- Update to 1.031
- Update distribution-detection code
- Define %%{__id_u} in a more portable way

* Fri Jan 13 2006 Paul Howarth <paul@city-fan.org> - 1.030-1
- Update to 1.030

* Sat Dec 31 2005 Paul Howarth <paul@city-fan.org> - 1.029-1
- Update to 1.029
- Simplify distribution-detection
- Clarify spec by removing __perl_version and __perl_package macros
- Unconditionally remove buildroot in %%clean and %%install
- Don't use macros in build-time command paths, hardcode them instead
- Fix directory ownership
- Use search.cpan.org URLs

* Tue Jul 26 2005 Paul Howarth <paul@city-fan.org> - 1.028-1
- Update to 1.028

* Thu Jul  7 2005 Paul Howarth <paul@city-fan.org> - 1.027-2
- Rewrite spec file in (mainly) Fedora Extras style
- Include full URL for source
- Fix URL
- Use MODULE_COMPAT dependency style and remove explicit perl dependency
- Remove MANIFEST from %%doc

* Wed Mar  9 2005 Paul Howarth <paul@city-fan.org> - 1.027-1
- Update to 1.027
- Update URL

* Wed Oct 27 2004 Paul Howarth <paul@city-fan.org> - 1.025-1
- Update to 1.025
- Tidy up spec file
- Add BuildRequires: perl-Test-Manifest to get working set of tests

* Mon May 10 2004 Paul Howarth <paul@city-fan.org> - 0.23-1
- Initial build
